from sqlalchemy import Column, Integer, DateTime, ForeignKey, Float, Enum, String
from sqlalchemy.orm import relationship
from datetime import datetime
import enum

from app.db.base import Base


class SubscriptionStatus(str, enum.Enum):
    ACTIVE = "active"
    EXPIRED = "expired"
    CANCELLED = "cancelled"
    PENDING = "pending"


class Subscription(Base):
    __tablename__ = "subscriptions"

    id = Column(Integer, primary_key=True, index=True)
    user_id = Column(Integer, ForeignKey("users.id"), nullable=False)
    membership_plan_id = Column(
        Integer, ForeignKey("membership_plans.id"), nullable=False
    )
    status = Column(Enum(SubscriptionStatus), default=SubscriptionStatus.PENDING)
    start_date = Column(DateTime, nullable=False)
    end_date = Column(DateTime, nullable=False)
    amount_paid = Column(Float, nullable=False)
    payment_reference = Column(String, nullable=True)
    created_at = Column(DateTime, default=datetime.utcnow)
    updated_at = Column(DateTime, default=datetime.utcnow, onupdate=datetime.utcnow)

    user = relationship("User", back_populates="subscriptions")
    membership_plan = relationship("MembershipPlan", back_populates="subscriptions")
    transactions = relationship("Transaction", back_populates="subscription")
